
import json
import pandas as pd



def process_jsonl_file(file_path, top_n_per_group, result, seen_uids):
    """
    读取 jsonl 文件，对每一行 group 数据，尽力从中选出 top_n_per_group 条不重复数据
    如果无法选够指定数量的数据，则跳过该 group 并打印警告信息。
    """
    with open(file_path, 'r', encoding='utf-8') as f:
        for line_idx, line in enumerate(f):
            line = line.strip()
            if not line:
                continue
            try:
                entry = json.loads(line)

                # 获取 group key 和对应的数据列表
                key = next(k for k in entry if k != "count")
                records = entry[key]

                selected = []
                added_count = 0

                # 遍历 records，直到选够 top_n_per_group 个不重复的数据
                for item in records:
                    uid = item.get('工单编号')

                    if added_count >= top_n_per_group:
                        break  # 已经选够了，退出

                    if uid and uid not in seen_uids:
                        seen_uids.add(uid)
                        selected.append(item)
                        result.append(item)
                        added_count += 1

                # 如果最终无法选满 top_n_per_group 条，可以给出警告或处理
                if added_count < top_n_per_group:
                    print(f"[Group {key}] Only found {added_count}/{top_n_per_group} unique items. Skipping this group.")
                    # 如果需要的话，可以从结果中移除已添加的记录
                    for item in selected:
                        result.remove(item)
                        seen_uids.discard(item.get('uid'))
                else:
                    print(f"[Group {key}] Successfully added {added_count} items.")

            except Exception as e:
                print(f"Error processing line {line_idx + 1}: {e}")
                continue

def load_data_to_memory(input_file):
    """
    读取jsonl文件，将数据存入result列表，工单编号存入seen_uids集合
    
    :param input_file: 输入jsonl文件路径
    :return: tuple(result列表, seen_uids集合)
    """
    result = []
    seen_uids = set()
    
    try:
        with open(input_file, 'r', encoding='utf-8') as f:
            for line in f:
                try:
                    # 解析JSON行数据
                    data = json.loads(line.strip())
                    
                    # 检查是否包含工单编号字段
                    if '工单编号' in data:
                        uid = data['工单编号']
                        
                        # 添加到结果列表和已见集合
                        result.append(data)
                        seen_uids.add(uid)
                    else:
                        print(f"警告：跳过缺少工单编号的记录: {data}")
                        
                except json.JSONDecodeError:
                    print(f"警告：跳过无法解析的行: {line}")
                    continue
                    
    except FileNotFoundError:
        print(f"错误：文件 {input_file} 不存在")
        return [], set()
    except Exception as e:
        print(f"读取文件时发生错误: {str(e)}")
        return [], set()
    
    print(f"成功加载 {len(result)} 条数据，发现 {len(seen_uids)} 个唯一工单编号")
    return result, seen_uids


def main():
    result = []
    seen_uids = set()

    result, seen_uids = load_data_to_memory("/data/zhaochsh01/buquan/12345/tool/output_prompt.jsonl")
    

    # Step 3: 处理 dhbq_count_instag.jsonl，每组前130条
    print("Step 3: Processing dhbq_count_instag.jsonl...")
    process_jsonl_file("/data/zhaochsh01/buquan/12345/count_result/12345_count_instag.jsonl", 3, result, seen_uids)

    # Step 4: 处理 dhbq_count_cluster.jsonl，每组前4条
    print("Step 4: Processing dhbq_count_cluster.jsonl...")
    process_jsonl_file("/data/zhaochsh01/buquan/12345/count_result/12345_count_cluster.jsonl", 3, result, seen_uids)

    # 最终写入输出文件
    output_file = "/data/zhaochsh01/buquan/12345/merge_result/merged_result_for_more_test.jsonl"
    with open(output_file, 'w', encoding='utf-8') as f:
        for item in result:
            f.write(json.dumps(item, ensure_ascii=False) + '\n')

    print(f"Total merged items: {len(result)}")
    print(f"Saved to: {output_file}")


if __name__ == "__main__":
    main()


