import json
from collections import defaultdict
import openpyxl

def count_categories_from_jsonl(input_file, output_xlsx):
    """
    读取jsonl文件，统计类别信息并输出到xlsx文件
    
    :param input_file: 输入的jsonl文件路径
    :param output_xlsx: 输出的xlsx文件路径
    """
    # 用于统计每个类别的数据量
    category_counts = defaultdict(int)
    total_categories = 0
    total_samples = 0
    
    # 1. 读取jsonl文件并统计
    with open(input_file, 'r', encoding='utf-8') as f:
        for line in f:
            try:
                data = json.loads(line.strip())
                answer = data.get('answer')
                if answer:
                    category_counts[answer] += 1
                    total_samples += 1
            except json.JSONDecodeError:
                print(f"警告：跳过无法解析的行: {line}")
                continue
    
    total_categories = len(category_counts)
    
    # 2. 创建Excel工作簿和工作表
    wb = openpyxl.Workbook()
    ws = wb.active
    ws.title = "类别统计"
    
    # 3. 写入表头
    headers = ["类别名称", "数据量", "占比(%)"]
    ws.append(headers)
    
    # 4. 写入统计数据
    for category, count in sorted(category_counts.items(), key=lambda x: x[1], reverse=True):
        percentage = (count / total_samples) * 100
        ws.append([category, count, f"{percentage:.2f}%"])
    
    # 5. 写入汇总信息
    ws.append([])  # 空行分隔
    ws.append(["总类别数", total_categories])
    ws.append(["总数据量", total_samples])
    
    # 6. 设置单元格样式
    # 设置列宽
    ws.column_dimensions['A'].width = 40  # 类别名称列
    ws.column_dimensions['B'].width = 15  # 数据量列
    ws.column_dimensions['C'].width = 15  # 占比列
    
    # 设置标题行样式
    for cell in ws[1]:
        cell.font = openpyxl.styles.Font(bold=True)
    
    # 7. 保存Excel文件
    wb.save(output_xlsx)
    print(f"统计完成！共{total_categories}个类别，{total_samples}条数据。结果已保存到{output_xlsx}")

# 使用示例
input_jsonl = "/data/zhaochsh01/buquan/12345/tool/output_prompt.jsonl"  # 替换为你的jsonl文件路径
output_excel = "12345category_stats.xlsx"  # 输出Excel文件路径
count_categories_from_jsonl(input_jsonl, output_excel)