import json
from collections import defaultdict

def select_and_transform_data(input_file, output_file, small_category_max=2, normal_samples=4, total_samples=250):
    """
    读取jsonl文件，按answer分类，小类别(<=2)全选，其他类别每类选指定条数数据，转换字段并保存
    
    :param input_file: 输入jsonl文件路径
    :param output_file: 输出jsonl文件路径
    :param small_category_max: 小类别的最大数据量阈值(<=此值视为小类别)
    :param normal_samples: 普通类别每类选取的样本数
    :param total_samples: 总共需要选取的样本数
    """
    # 按answer分类存储数据
    categorized_data = defaultdict(list)
    
    # 1. 读取并分类数据
    with open(input_file, 'r', encoding='utf-8') as f:
        for line in f:
            try:
                data = json.loads(line.strip())
                answer = data.get('answer')
                if answer:
                    categorized_data[answer].append(data)
            except json.JSONDecodeError:
                print(f"警告：跳过无法解析的行: {line}")
                continue
    
    # 分离小类别和普通类别
    small_categories = {k: v for k, v in categorized_data.items() if len(v) <= small_category_max}
    normal_categories = {k: v for k, v in categorized_data.items() if len(v) > small_category_max}
    
    # 2. 先选取小类别的所有数据
    selected_data = []
    selected_count = 0
    
    for category, items in small_categories.items():
        # 全取小类别的数据
        for item in items:
            transformed = {
                "工单编号": item["uid"],
                "data": item["data"],
                "answer": item["answer"]
            }
            selected_data.append(transformed)
            selected_count += 1
    
    # 3. 从普通类别中选取数据，直到达到总数
    for category, items in normal_categories.items():
        if selected_count >= total_samples:
            break
        
        # 计算还能取多少数据
        remaining = total_samples - selected_count
        if remaining <= 0:
            break
        
        # 取min(普通类别样本数, 当前类别数据量, 剩余需要的数据量)
        take = min(normal_samples, len(items), remaining)
        
        # 选取数据（这里简单取前take条，如需随机可改为random.sample）
        for item in items[:take]:
            transformed = {
                "工单编号": item["uid"],
                "data": item["data"],
                "answer": item["answer"]
            }
            selected_data.append(transformed)
            selected_count += 1
    
    # 4. 保存结果到jsonl文件
    with open(output_file, 'w', encoding='utf-8') as f:
        for item in selected_data:
            f.write(json.dumps(item, ensure_ascii=False) + '\n')
    
    print(f"处理完成！共选取{selected_count}条数据，保存到{output_file}")
    print("分类统计：")
    stat = {k: len([d for d in selected_data if d['answer'] == k]) for k in categorized_data}
    for k, v in stat.items():
        print(f"{k}: {v}条 (共{categorized_data[k]}条)")

# 使用示例
input_file = "/data/zhaochsh01/buquan/12345/count_result/12345_prompt.jsonl"  # 替换为你的输入文件路径
output_file = "output_prompt.jsonl"  # 输出文件路径
select_and_transform_data(input_file, output_file, small_category_max=2, normal_samples=4, total_samples=250)